# TorchGlyph

[![Unit Tests](https://github.com/speedcell4/torchglyph/actions/workflows/unit-tests.yml/badge.svg)](https://github.com/speedcell4/torchglyph/actions/workflows/unit-tests.yml)
[![PyPI version](https://badge.fury.io/py/torchglyph.svg)](https://badge.fury.io/py/torchglyph)
[![Downloads](https://pepy.tech/badge/torchglyph)](https://pepy.tech/project/torchglyph)

Data Processor Combinators for Natural Language Processing.

## Requirements

- Python 3.8
- PyTorch 1.10.2

## Installation

`python -m pip install torchglyph`
